@@ -1,8 +1,9 @@
 import copy
 import re
+import apscheduler
 
 from function_scheduling_distributed_framework import frame_config
-from function_scheduling_distributed_framework.consumers.base_consumer import ExceptionForRequeue, ExceptionForRetry, AbstractConsumer, ConsumersManager,FunctionResultStatusPersistanceConfig
+from function_scheduling_distributed_framework.consumers.base_consumer import ExceptionForRequeue, ExceptionForRetry, AbstractConsumer, ConsumersManager, FunctionResultStatusPersistanceConfig
 from function_scheduling_distributed_framework.publishers.base_publisher import PriorityConsumingControlConfig
 from function_scheduling_distributed_framework.factories.publisher_factotry import get_publisher
 from function_scheduling_distributed_framework.factories.consumer_factory import get_consumer
@@ -13,15 +14,22 @@ from function_scheduling_distributed_framework.utils import nb_print, patch_prin
 def patch_frame_config(MONGO_CONNECT_URL: str = None,
 
                        RABBITMQ_USER: str = None,
-                       RABBITMQ_PASS: str = None, RABBITMQ_HOST: str = None,
-                       RABBITMQ_PORT: int = None, RABBITMQ_VIRTUAL_HOST: str = None,
+                       RABBITMQ_PASS: str = None,
+                       RABBITMQ_HOST: str = None,
+                       RABBITMQ_PORT: int = None,
+                       RABBITMQ_VIRTUAL_HOST: str = None,
 
-                       REDIS_HOST: str = None, REDIS_PASSWORD: str = None, REDIS_PORT: int = None, REDIS_DB: int = None,
+                       REDIS_HOST: str = None,
+                       REDIS_PASSWORD: str = None,
+                       REDIS_PORT: int = None,
+                       REDIS_DB: int = None,
 
                        NSQD_TCP_ADDRESSES: list = None,
                        NSQD_HTTP_CLIENT_HOST: str = None,
                        NSQD_HTTP_CLIENT_PORT: int = None,
-                       KAFKA_BOOTSTRAP_SERVERS: list = None
+                       KAFKA_BOOTSTRAP_SERVERS: list = None,
+
+                       SQLACHEMY_ENGINE_URL='sqlite:////sqlachemy_queues/queues.db'
 
                        ):
     """
